# -*- coding: utf-8 -*-

# Copyright 2016 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


class TrigAlertsInterface(object):

    def __init__(self, user_token, rest_client):
        self.token = user_token
        self.rest_client = rest_client

    def getTriggeredAlerts(self):

        """Return all triggered alerts

        :rtype: array
        """

        path = '/triggeredalerts/' + self.token
        return self.rest_client.sendGetRequest(path)

    def getTriggeredAlertsLast24Hours(self):

        """Return all triggered alerts in the last 24 hours

        :rtype: array
        """

        path = '/triggeredalerts/' + self.token + "/last24"
        return self.rest_client.sendGetRequest(path)
