# -*- coding: utf-8 -*-

# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from interfaces.rest import RestClient
from interfaces.logs import LogsInterface
from interfaces.metrics import MetricsInterface
from interfaces.alerts import AlertsInterface
from interfaces.trigalerts import TrigAlertsInterface


class ZeusClient(MetricsInterface, LogsInterface, AlertsInterface,
                 TrigAlertsInterface):

    """Zeus Client class, implementing wrapper methods for the
    Zeus API.

    """

    def __init__(self, user_token, server):
        self.token = user_token
        rest_client = RestClient(server)
        self.server = rest_client.server
        super(ZeusClient, self).__init__(user_token, rest_client)
